Animation class

Implementers

Constructors

Animation(Mobject mobject, {double runTime = DEFAULT_ANIMATION_RUN_TIME, RateFunc rateFunc = smooth, double lagRatio = DEFAULT_ANIMATION_LAG_RATIO})
Animation.fromCopy(Animation anim)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lagRatio ↔ double
getter/setter pair
mobject ↔ Mobject
getter/setter pair
name ↔ String
getter/setter pair
rateFunc ↔ RateFunc
getter/setter pair
remover ↔ bool
getter/setter pair
runTime ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startingMobject ↔ Mobject
getter/setter pair
suspendMobjectUpdating ↔ bool
getter/setter pair

Methods

begin() → void
cleanUpFromScene(Scene scene) → void
copy() → Animation
createStartingMobject() → Mobject
finish() → void
getAllFamiliesZipped() → List<List<Mobject>>
getAllMobjects() → List<Mobject>
getAllMobjectsToUpdate() → List<Mobject>
getName() → String
getRateFunc() → RateFunc
getRunTime() → double
getSubAlpha(double alpha, int i, int numSubmobjects) → double
interpolate(double alpha) → void
interpolateMobject(double alpha) → void
interpolateSubMobject(List<Mobject> mobs, double subAlpha) → void
isRemover() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setName(String name) → void
setRateFunc(RateFunc rateFunc) → void
setRunTime(double runTime) → void
toString() → String
A string representation of this object.
override
update(double alpha) → void
updateMobjects(double dt) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited