TipStyle class

Inheritance

Constructors

TipStyle({Color? fillColor, Color? strokeColor, double strokeWidth = 0, Color? backgroundStrokeColor, double backgroundStrokeWidth = 0})
TipStyle.copyFrom(TipStyle style)

Properties

backgroundStrokeColors → List<Color>?
finalinherited
backgroundStrokeWidth → double
finalinherited
fillColors → List<Color>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColors → List<Color>?
finalinherited
strokeWidth → double
finalinherited

Methods

copy() → TipStyle
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withChange({Color? fillColor, Color? strokeColor, double? strokeWidth, Color? backgroundStrokeColor, double? backgroundStrokeWidth, List<Color>? fillColors, List<Color>? strokeColors, List<Color>? backgroundStrokeColors}) → TipStyle
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited