InteractiveMobject class abstract

Inheritance
Implementers

Properties

color ↔ Color
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setterinherited
mobject ↔ Mobject
getter/setter pair
name ↔ String
getter/setter pairinherited
points ↔ List<Vector3>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submobjects ↔ List<Mobject>
getter/setter pairinherited
target ↔ Mobject?
getter/setter pairinherited
updaters ↔ List<Updater>
getter/setter pairinherited
updatingSuspended ↔ bool
getter/setter pairinherited

Methods

add(List<Mobject> mobjects) → void
inherited
addEventListener<IEvent extends Event>(EventType eventType, EventCallBack<IEvent> callBack) → EventListener<IEvent>
addNMoreSubmobjects(int n) → void
inherited
addToBack(List<Mobject> mobjects) → void
inherited
addToFront(List<Mobject> mobjects) → void
inherited
addUpdater(Updater updater, {int? index, bool callUpdater = true}) → void
inherited
alignData(Mobject mob) → void
inherited
alignOnBorder(Vector3 direction, {double? buffer}) → void
inherited
alignPoints(Mobject mob) → void
inherited
alignPointsWithLarger(Mobject largerMob) → void
inherited
alignSubmobjects(Mobject mob2) → void
inherited
alignToMobject(Mobject mob, {Vector3? direction}) → void
inherited
alignToPoint(Vector3 point, {Vector3? direction}) → void
inherited
applyComplexFunction(Complex func(Complex)) → void
inherited
applyFunction(Vector3 func(Vector3)) → void
inherited
applyMatrix(Array mat) → void
inherited
applyOverPoints({required Vector3 func(Vector3), Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
applyToFamily(Mobject func(Mobject), {bool useFamilyWithPoints = true}) → void
inherited
arrange({Vector3 direction = RIGHT, bool center = true, double buffer = DEFAULT_MOBJECT_TO_MOBJECT_BUFFER, Vector3 alignedEdge = ORIGIN, Vector3 coordinateMask = const Vector3(1, 1, 1)}) → void
inherited
arrangeInGrid({int? numRows, int? numCols, bool center = true, double buffer = DEFAULT_MOBJECT_TO_MOBJECT_BUFFER, Vector3 alignedEdge = ORIGIN, Vector3 coordinateMask = const Vector3(1, 1, 1)}) → void
inherited
become(Mobject mob, {bool copySubmobjects = true}) → void
inherited
becomePartial(Mobject mob, double a, double b) → void
inherited
bindEventListeners() → void
center({Vector3 mask = const Vector3(1, 1, 1)}) → void
inherited
centerOnXAxis() → void
inherited
centerOnYAxis() → void
inherited
centerOnZAxis() → void
inherited
clearUpdaters({bool recursive = true}) → void
inherited
copy() → Mobject
inherited
createGroup<MobjectType extends Mobject>(List<MobjectType> mobs) → Mobject
inherited
fade({double darkness = 0.5, bool family = true}) → void
inherited
fadeTo(Color color, double alpha, {bool family = true}) → void
inherited
flip({Vector3 axis = UP, Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
generatePoints() → void
inherited
generateTarget() → Mobject
inherited
getAllPoints() → List<Vector3>
inherited
getBottom() → Vector3
inherited
getBoundaryPoint(Vector3 direction) → Vector3
inherited
getCenter() → Vector3
inherited
getCenterOfMass() → Vector3
inherited
getColor() → Color
inherited
getCoord(int dim, {Vector3? direction}) → double
inherited
getCorner(Vector3 corner) → Vector3
inherited
getCriticalPoint(Vector3 direction) → Vector3
inherited
getDepth() → double
inherited
getEdgeCenter(Vector3 edge) → Vector3
inherited
getEnd() → Vector3
inherited
getExtremumAlongDim({List<Vector3>? points, int dim = 0, int key = 0}) → double
inherited
getFamily() → List<Mobject>
inherited
getFamilyUpdaters() → List<Updater>
inherited
getFamilyWithPoints() → List<Mobject>
inherited
getHeight() → double
inherited
getLeft() → Vector3
inherited
getNadir() → Vector3
inherited
getName() → String
inherited
getNumPoints() → int
inherited
getPieces(int numPieces) → Group
inherited
getPointMobject({Vector3? center}) → Mobject
inherited
getPointsDefiningBoundary() → List<Vector3>
inherited
getPos({Vector3? direction}) → Vector3
inherited
getRight() → Vector3
inherited
getStart() → Vector3
inherited
getStartAndEnd() → Tuple2<Vector3, Vector3>
inherited
getTop() → Vector3
inherited
getUpdaters() → List<Updater>
inherited
getWidth() → double
inherited
getX({Vector3? direction}) → double
inherited
getY({Vector3? direction}) → double
inherited
getZ({Vector3? direction}) → double
inherited
getZenith() → Vector3
inherited
getZIndexReferencePoint() → Vector3
inherited
hasNoPoints() → bool
inherited
hasPoints() → bool
inherited
hasUpdaters() → bool
inherited
initColors() → void
inherited
interpolate(Mobject a, Mobject b, double alpha, {PathFunc? pathFunc}) → void
inherited
interpolateColor(Mobject a, Mobject b, double alpha) → void
inherited
isInside(Vector3 pt, {double buff = SMALL_BUFFER}) → bool
inherited
isOffScreen() → bool
inherited
lengthOverDim(int dim) → double
inherited
matchColor(Mobject mob) → void
inherited
matchCoord(Mobject mob, int dim, {Vector3? direction}) → void
inherited
matchDepth(Mobject mob, {Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint, bool stretch = false}) → void
inherited
matchDimSize(Mobject mob, int dim, {Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint, bool stretch = false}) → void
inherited
matchHeight(Mobject mob, {Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint, bool stretch = false}) → void
inherited
matchUpdaters(Mobject mob) → void
inherited
matchWidth(Mobject mob, {Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint, bool stretch = false}) → void
inherited
matchX(Mobject mob, {Vector3? direction}) → void
inherited
matchY(Mobject mob, {Vector3? direction}) → void
inherited
matchZ(Mobject mob, {Vector3? direction}) → void
inherited
moveToMobject(Mobject target, {Vector3? alignedEdge, Vector3? coordinateMask}) → void
inherited
moveToPoint(Vector3 target, {Vector3? alignedEdge, Vector3? coordinateMask}) → void
inherited
nextToMobject(Mobject mobject, {Vector3 direction = RIGHT, double buffer = DEFAULT_MOBJECT_TO_MOBJECT_BUFFER, Vector3 alignedEdge = ORIGIN, Vector3 coordinateMask = const Vector3(1, 1, 1)}) → void
inherited
nextToPoint(Vector3 targetPoint, {Vector3 direction = RIGHT, double buffer = DEFAULT_MOBJECT_TO_MOBJECT_BUFFER, Vector3 alignedEdge = ORIGIN, Vector3 coordinateMask = const Vector3(1, 1, 1)}) → void
inherited
nonEmptySubmobjects() → List<Mobject>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nullPointAlign(Mobject m2) → void
inherited
pointFromProportion(double alpha) → Vector3
inherited
pointwiseBecomePartial(Mobject mob, double a, double b) → void
inherited
pushSelfIntoSubmobjects() → void
inherited
putStartAndEndOn(Vector3 start, Vector3 end) → void
inherited
remove(List<Mobject> mobjects) → void
inherited
removeEventListener(EventListener<Event> listener) → void
removeUpdater(Updater updater) → void
inherited
repeat(int count) → void
inherited
replace(Mobject mob, {int dimToMatch = 0, bool stretch = false}) → void
inherited
rescaleToFit(double length, int dim, {bool stretch = false, Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint}) → void
inherited
resetPoints() → void
inherited
resumeUpdating({bool recursive = true}) → void
inherited
reversePoints() → void
inherited
reverseSubmobjects({bool recursive = false}) → void
inherited
rotate(double angle, {Vector3 axis = OUT, Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
rotateAboutOrigin(double angle, {Vector3 axis = OUT}) → void
inherited
scale(Vector3 scaleFactor, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
scaleUniformly(double scaleFactor, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
setColor({required Color color, bool family = true}) → void
inherited
setColorByGradient(List<Color> colors) → void
inherited
setColorByRadialGradient({Vector3? center, double? radius, required Color innerColor, required Color outerColor}) → void
inherited
setCoord(double value, int dim, {Vector3? direction}) → void
inherited
setDepth(double depth, {bool stretch = false, Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
setHeight(double height, {bool stretch = false, Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
setSubmobjectColorsByGradient(List<Color> colors) → void
inherited
setSubmobjectColorsByRadialGradient({Vector3? center, double? radius, required Color innerColor, required Color outerColor}) → void
inherited
setWidth(double width, {bool stretch = false, Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
setX(double x, {Vector3? direction}) → void
inherited
setY(double y, {Vector3? direction}) → void
inherited
setZ(double z, {Vector3? direction}) → void
inherited
shift(Vector3 delta) → void
inherited
shiftOntoScreen({double? buffer}) → void
inherited
shuffle({bool recursive = false}) → void
inherited
sort({double pointToNumFunc(Vector3)?, double keyFunc(Mobject)?}) → void
inherited
spaceOutSubmobjects({double factor = 1.5, Vector3 aboutEdge = ORIGIN, Vector3? aboutPoint}) → void
inherited
split() → List<Mobject>
inherited
stretch(double scaleFactor, int dim, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
stretchToFitDepth(double depth, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
stretchToFitHeight(double height, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
stretchToFitWidth(double width, {Vector3? aboutPoint, Vector3 aboutEdge = ORIGIN}) → void
inherited
surround(Mobject mob, {int dimToMatch = 0, bool stretch = false, double? buffer}) → void
inherited
suspendUpdating({bool recursive = true}) → void
inherited
throwErrorIfNoPoints(String? method) → void
inherited
toCorner({Vector3 corner = DL, double buffer = DEFAULT_MOBJECT_TO_EDGE_BUFFER}) → void
inherited
toEdge({Vector3 edge = LEFT, double buffer = DEFAULT_MOBJECT_TO_EDGE_BUFFER}) → void
inherited
toOriginalColor() → void
inherited
toString() → String
A string representation of this object.
inherited
unbindEventListeners() → void
update({double dt = 0, bool recursive = true}) → void
inherited
wag({Vector3 direction = RIGHT, Vector3 axis = DOWN, double wagFactor = 1.0}) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int i) → Mobject
inherited