KeyReleasedEvent class

Inheritance

Constructors

KeyReleasedEvent({required String keyReleased})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCharacter → bool
no setterinherited
key ↔ String
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ EventType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited