Vector3 class

Constructors

Vector3(double x, double y, double z)
const
Vector3.fromArray(Array v)
factory
Vector3.fromValue(double k)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final
z → double
final

Methods

abs() → Vector3
angle() → double
angleBetween(Vector3 vec) → double
applyFunction(double func(double)) → Vector3
applyQuaternion(Array quat) → Vector3
copy() → Vector3
cross(Vector3 b) → Vector3
dot(Vector3 b) → double
getComponent(int i) → double
isFinite() → bool
isInfinite() → bool
isNan() → bool
matMul(Array matrix) → Vector3
norm() → double
normalize() → Vector3
normSquared() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(double angle, {Vector3 axis = OUT}) → Vector3
scale(num k) → Vector3
sign() → Vector3
toArray({bool row = false}) → Array
toList() → List<double>
toString() → String
A string representation of this object.
override
withComponent(int index, double value) → Vector3
withCoords({double? x, double? y, double? z}) → Vector3

Operators

operator *(dynamic v) → Vector3
operator +(dynamic v) → Vector3
operator -(dynamic v) → Vector3
operator /(dynamic v) → Vector3
operator ==(Object other) → bool
The equality operator.
override
operator [](int i) → double